@@ -7,7 +7,7 @@ import shutil
 import argparse
 import pathlib
 
-from . import implementation
+implementation = "3.11.0"
 
 
 def main():
@@ -254,7 +254,7 @@ def main():
 
         case 'make_package':
             package_name = args.package_name
-            package_path = args.src_dir
+            package_path = os.getcwd()
             exclude_dirs = args.exclude_dirs
             output_path = args.output_path
             from . import make_package
